==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/VerticalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let VerticalAnchoredCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class VerticalAnchoredCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (VerticalAnchoredCategorySeriesDescriptionMetadata.a == null) {
                VerticalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VerticalAnchoredCategorySeriesDescriptionMetadata.c(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(VerticalAnchoredCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            VerticalAnchoredCategorySeriesDescriptionMetadata.b(a);
            a.ac("VerticalAnchoredCategorySeries", VerticalAnchoredCategorySeriesDescriptionMetadata.a);
        }
    }
    VerticalAnchoredCategorySeriesDescriptionMetadata.$t = markType(VerticalAnchoredCategorySeriesDescriptionMetadata, 'VerticalAnchoredCategorySeriesDescriptionMetadata');
    VerticalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return VerticalAnchoredCategorySeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/VerticalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let VerticalAnchoredCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class VerticalAnchoredCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (VerticalAnchoredCategorySeriesDescriptionMetadata.a == null) {
                VerticalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VerticalAnchoredCategorySeriesDescriptionMetadata.c(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(VerticalAnchoredCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            VerticalAnchoredCategorySeriesDescriptionMetadata.b(a);
            a.ad("VerticalAnchoredCategorySeries", VerticalAnchoredCategorySeriesDescriptionMetadata.a);
        }
    }
    VerticalAnchoredCategorySeriesDescriptionMetadata.$t = markType(VerticalAnchoredCategorySeriesDescriptionMetadata, 'VerticalAnchoredCategorySeriesDescriptionMetadata');
    VerticalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return VerticalAnchoredCategorySeriesDescriptionMetadata;
})();
